@@ -1,12 +1,16 @@
 # Copyright 2021 VMware, Inc.
 # SPDX-License-Identifier: Apache-2.0
+import logging
+
 import click
 from tabulate import tabulate
 from vdk.api.plugin.hook_markers import hookimpl
+from vdk.internal.builtin_plugins.connection.recovery_cursor import RecoveryCursor
 from vdk.internal.builtin_plugins.run.job_context import JobContext
 from vdk.internal.core.config import Configuration
 from vdk.internal.core.config import ConfigurationBuilder
 from vdk.plugin.impala.impala_connection import ImpalaConnection
+from vdk.plugin.impala.impala_error_handler import ImpalaErrorHandler
 
 
 def _connection_by_configuration(configuration: Configuration):
@@ -141,3 +145,17 @@ def initialize_job(context: JobContext) -> None:
         "IMPALA",
         lambda: _connection_by_configuration(context.core_context.configuration),
     )
+
+
+@hookimpl
+def db_connection_recover_operation(recovery_cursor: RecoveryCursor) -> None:
+    impala_error_handler = ImpalaErrorHandler()
+
+    if impala_error_handler.handle_error(
+        recovery_cursor.get_exception(), recovery_cursor
+    ):
+        logging.getLogger(__name__).info(
+            "Error handled successfully! Query execution has succeeded."
+        )
+    else:
+        raise recovery_cursor.get_exception()
